import{E as Ot,F as Mt,d as Et,e as Kt,i as E,j as Ht,na as qt,oa as ot,pa as Pt,qa as Rt}from"./chunk-VYRWAFSM.js";import{E as et,Ha as Lt,Ia as at,J as S,La as jt,P as nt,ba as it,k as Bt,u as It,v as Vt,w as R,wa as Ft,xa as At}from"./chunk-2XIOYYFS.js";import{D as C,F as G,K as J,m as kt,o as Dt,p as $t,t as U}from"./chunk-UOI75ONS.js";import{$c as yt,Ab as r,Ac as q,Bc as P,Cb as vt,Cc as W,Gc as k,Hc as m,Ia as ft,Ic as _,Ja as N,Jc as y,Ka as A,Kd as g,Lb as K,Ld as wt,Na as D,Nd as u,Od as xt,Qb as f,Qc as F,Rb as mt,Rc as T,Rd as L,Sc as c,Ta as Z,Tc as b,Ub as $,Vb as gt,Wb as l,Xa as x,Ya as ht,Za as j,Zc as _t,ic as h,jc as p,jd as Tt,lc as B,ld as Ct,nc as tt,ra as M,rc as I,sa as ut,ta as dt,wc as d,xc as v,ya as w,yc as V,zc as H}from"./chunk-4HFZZ7HS.js";import{e as Q}from"./chunk-SZAW6ZBW.js";function ne(e,s){e&1&&P(0)}function ie(e,s){if(e&1&&l(0,ne,1,0,"ng-container",11),e&2){let t=m(2);p("ngTemplateOutlet",t.prevIconTemplate||t._prevIconTemplate)}}function ae(e,s){e&1&&V(0,"ChevronLeftIcon")}function oe(e,s){if(e&1){let t=W();d(0,"button",10,3),k("click",function(){N(t);let n=m();return A(n.onPrevButtonClick())}),l(2,ie,1,1,"ng-container")(3,ae,1,0,"ChevronLeftIcon"),v()}if(e&2){let t=m();h("aria-label",t.prevButtonAriaLabel)("tabindex",t.tabindex())("data-pc-group-section","navigator"),r(2),I(t.prevIconTemplate||t._prevIconTemplate?2:3)}}function se(e,s){e&1&&P(0)}function re(e,s){if(e&1&&l(0,se,1,0,"ng-container",11),e&2){let t=m(2);p("ngTemplateOutlet",t.nextIconTemplate||t._nextIconTemplate)}}function le(e,s){e&1&&V(0,"ChevronRightIcon")}function ce(e,s){if(e&1){let t=W();d(0,"button",12,4),k("click",function(){N(t);let n=m();return A(n.onNextButtonClick())}),l(2,re,1,1,"ng-container")(3,le,1,0,"ChevronRightIcon"),v()}if(e&2){let t=m();h("aria-label",t.nextButtonAriaLabel)("tabindex",t.tabindex())("data-pc-group-section","navigator"),r(2),I(t.nextIconTemplate||t._nextIconTemplate?2:3)}}function be(e,s){e&1&&y(0)}var Ut,Gt,Jt,Xt,Yt,Zt,te,z,ee,pe,ue,St,X,st,rt,lt,O,Qt,ct=Q(()=>{J();J();L();L();At();Ht();Kt();jt();Rt();Rt();qt();Ut=["previcon"],Gt=["nexticon"],Jt=["content"],Xt=["prevButton"],Yt=["nextButton"],Zt=["inkbar"],te=["tabs"],z=["*"],ee=e=>({"p-tablist-viewport":e});pe=({dt:e})=>`
.p-tabs {
    display: flex;
    flex-direction: column;
}

.p-tablist {
    display: flex;
    position: relative;
}

.p-tabs-scrollable > .p-tablist {
    overflow: hidden;
}

.p-tablist-viewport {
    overflow-x: auto;
    overflow-y: hidden;
    scroll-behavior: smooth;
    scrollbar-width: none;
    overscroll-behavior: contain auto;
}

.p-tablist-viewport::-webkit-scrollbar {
    display: none;
}

.p-tablist-tab-list {
    position: relative;
    display: flex;
    background: ${e("tabs.tablist.background")};
    border-style: solid;
    border-color: ${e("tabs.tablist.border.color")};
    border-width: ${e("tabs.tablist.border.width")};
}

.p-tablist-content {
    flex-grow: 1;
}

.p-tablist-nav-button {
    all: unset;
    position: absolute !important;
    flex-shrink: 0;
    top: 0;
    z-index: 2;
    height: 100%;
    display: flex;
    align-items: center;
    justify-content: center;
    background: ${e("tabs.nav.button.background")};
    color: ${e("tabs.nav.button.color")};
    width: ${e("tabs.nav.button.width")};
    transition: color ${e("tabs.transition.duration")}, outline-color ${e("tabs.transition.duration")}, box-shadow ${e("tabs.transition.duration")};
    box-shadow: ${e("tabs.nav.button.shadow")};
    outline-color: transparent;
    cursor: pointer;
}

.p-tablist-nav-button:focus-visible {
    z-index: 1;
    box-shadow: ${e("tabs.nav.button.focus.ring.shadow")};
    outline: ${e("tabs.nav.button.focus.ring.width")} ${e("tabs.nav.button.focus.ring.style")} ${e("tabs.nav.button.focus.ring.color")};
    outline-offset: ${e("tabs.nav.button.focus.ring.offset")};
}

.p-tablist-nav-button:hover {
    color: ${e("tabs.nav.button.hover.color")};
}

.p-tablist-prev-button {
    left: 0;
}

.p-tablist-next-button {
    right: 0;
}

.p-tab {
    display: flex;
    align-items: center;
    flex-shrink: 0;
    cursor: pointer;
    user-select: none;
    position: relative;
    border-style: solid;
    white-space: nowrap;
    gap: ${e("tabs.tab.gap")};
    background: ${e("tabs.tab.background")};
    border-width: ${e("tabs.tab.border.width")};
    border-color: ${e("tabs.tab.border.color")};
    color: ${e("tabs.tab.color")};
    padding: ${e("tabs.tab.padding")};
    font-weight: ${e("tabs.tab.font.weight")};
    transition: background ${e("tabs.transition.duration")}, border-color ${e("tabs.transition.duration")}, color ${e("tabs.transition.duration")}, outline-color ${e("tabs.transition.duration")}, box-shadow ${e("tabs.transition.duration")};
    margin: ${e("tabs.tab.margin")};
    outline-color: transparent;
}

.p-tab:not(.p-disabled):focus-visible {
    z-index: 1;
    box-shadow: ${e("tabs.tab.focus.ring.shadow")};
    outline: ${e("tabs.tab.focus.ring.width")} ${e("tabs.tab.focus.ring.style")} ${e("tabs.tab.focus.ring.color")};
    outline-offset: ${e("tabs.tab.focus.ring.offset")};
}

.p-tab:not(.p-tab-active):not(.p-disabled):hover {
    background: ${e("tabs.tab.hover.background")};
    border-color: ${e("tabs.tab.hover.border.color")};
    color: ${e("tabs.tab.hover.color")};
}

.p-tab-active {
    background: ${e("tabs.tab.active.background")};
    border-color: ${e("tabs.tab.active.border.color")};
    color: ${e("tabs.tab.active.color")};
}

.p-tabpanels {
    background: ${e("tabs.tabpanel.background")};
    color: ${e("tabs.tabpanel.color")};
    padding: ${e("tabs.tabpanel.padding")};
    outline: 0 none;
}

.p-tabpanel:focus-visible {
    box-shadow: ${e("tabs.tabpanel.focus.ring.shadow")};
    outline: ${e("tabs.tabpanel.focus.ring.width")} ${e("tabs.tabpanel.focus.ring.style")} ${e("tabs.tabpanel.focus.ring.color")};
    outline-offset: ${e("tabs.tabpanel.focus.ring.offset")};
}

.p-tablist-active-bar {
    z-index: 1;
    display: block;
    position: absolute;
    bottom: ${e("tabs.active.bar.bottom")};
    height: ${e("tabs.active.bar.height")};
    background: ${e("tabs.active.bar.background")};
    transition: 250ms cubic-bezier(0.35, 0, 0.25, 1);
}
`,ue={root:({props:e})=>["p-tabs p-component",{"p-tabs-scrollable":e.scrollable}]},St=(()=>{class e extends Et{name="tabs";theme=pe;classes=ue;static \u0275fac=(()=>{let t;return function(n){return(t||(t=D(e)))(n||e)}})();static \u0275prov=ut({token:e,factory:e.\u0275fac})}return e})(),X=(()=>{class e extends E{prevIconTemplate;nextIconTemplate;templates;content;prevButton;nextButton;inkbar;tabs;pcTabs=w(M(()=>O));isPrevButtonEnabled=j(!1);isNextButtonEnabled=j(!1);resizeObserver;showNavigators=u(()=>this.pcTabs.showNavigators());tabindex=u(()=>this.pcTabs.tabindex());scrollable=u(()=>this.pcTabs.scrollable());constructor(){super(),xt(()=>{this.pcTabs.value(),G(this.platformId)&&setTimeout(()=>{this.updateInkBar()})})}get prevButtonAriaLabel(){return this.config.translation.aria.previous}get nextButtonAriaLabel(){return this.config.translation.aria.next}ngAfterViewInit(){super.ngAfterViewInit(),this.showNavigators()&&G(this.platformId)&&(this.updateButtonState(),this.bindResizeObserver())}_prevIconTemplate;_nextIconTemplate;ngAfterContentInit(){this.templates.forEach(t=>{switch(t.getType()){case"previcon":this._prevIconTemplate=t.template;break;case"nexticon":this._nextIconTemplate=t.template;break}})}ngOnDestroy(){this.unbindResizeObserver(),super.ngOnDestroy()}onScroll(t){this.showNavigators()&&this.updateButtonState(),t.preventDefault()}onPrevButtonClick(){let t=this.content.nativeElement,i=S(t),n=Math.abs(t.scrollLeft)-i,a=n<=0?0:n;t.scrollLeft=nt(t)?-1*a:a}onNextButtonClick(){let t=this.content.nativeElement,i=S(t)-this.getVisibleButtonWidths(),n=t.scrollLeft+i,a=t.scrollWidth-i,o=n>=a?a:n;t.scrollLeft=nt(t)?-1*o:o}updateButtonState(){let t=this.content?.nativeElement,i=this.el?.nativeElement,{scrollWidth:n,offsetWidth:a}=t,o=Math.abs(t.scrollLeft),Y=S(t);this.isPrevButtonEnabled.set(o!==0),this.isNextButtonEnabled.set(i.offsetWidth>=a&&o!==n-Y)}updateInkBar(){let t=this.content?.nativeElement,i=this.inkbar?.nativeElement,n=this.tabs?.nativeElement,a=It(t,'[data-pc-name="tab"][data-p-active="true"]');i&&(i.style.width=Bt(a)+"px",i.style.left=et(a).left-et(n).left+"px")}getVisibleButtonWidths(){let t=this.prevButton?.nativeElement,i=this.nextButton?.nativeElement;return[t,i].reduce((n,a)=>a?n+S(a):n,0)}bindResizeObserver(){this.resizeObserver=new ResizeObserver(()=>this.updateButtonState()),this.resizeObserver.observe(this.el.nativeElement)}unbindResizeObserver(){this.resizeObserver&&(this.resizeObserver.unobserve(this.el.nativeElement),this.resizeObserver=null)}static \u0275fac=function(i){return new(i||e)};static \u0275cmp=f({type:e,selectors:[["p-tablist"]],contentQueries:function(i,n,a){if(i&1&&(F(a,Ut,4),F(a,Gt,4),F(a,Lt,4)),i&2){let o;c(o=b())&&(n.prevIconTemplate=o.first),c(o=b())&&(n.nextIconTemplate=o.first),c(o=b())&&(n.templates=o)}},viewQuery:function(i,n){if(i&1&&(T(Jt,5),T(Xt,5),T(Yt,5),T(Zt,5),T(te,5)),i&2){let a;c(a=b())&&(n.content=a.first),c(a=b())&&(n.prevButton=a.first),c(a=b())&&(n.nextButton=a.first),c(a=b())&&(n.inkbar=a.first),c(a=b())&&(n.tabs=a.first)}},hostVars:5,hostBindings:function(i,n){i&2&&(h("data-pc-name","tablist"),B("p-tablist",!0)("p-component",!0))},features:[$],ngContentSelectors:z,decls:9,vars:6,consts:[["content",""],["tabs",""],["inkbar",""],["prevButton",""],["nextButton",""],["type","button","pRipple","",1,"p-tablist-nav-button","p-tablist-prev-button"],[1,"p-tablist-content",3,"scroll","ngClass"],["role","tablist",1,"p-tablist-tab-list"],["role","presentation",1,"p-tablist-active-bar"],["type","button","pRipple","",1,"p-tablist-nav-button","p-tablist-next-button"],["type","button","pRipple","",1,"p-tablist-nav-button","p-tablist-prev-button",3,"click"],[4,"ngTemplateOutlet"],["type","button","pRipple","",1,"p-tablist-nav-button","p-tablist-next-button",3,"click"]],template:function(i,n){if(i&1){let a=W();_(),l(0,oe,4,4,"button",5),d(1,"div",6,0),k("scroll",function(Y){return N(a),A(n.onScroll(Y))}),d(3,"div",7,1),y(5),V(6,"span",8,2),v()(),l(8,ce,4,4,"button",9)}i&2&&(I(n.showNavigators()&&n.isPrevButtonEnabled()?0:-1),r(),p("ngClass",Ct(4,ee,n.scrollable())),r(5),h("data-pc-section","inkbar"),r(2),I(n.showNavigators()&&n.isNextButtonEnabled()?8:-1))},dependencies:[C,kt,U,Ot,Mt,Pt,ot,at],encapsulation:2,changeDetection:0})}return e})(),st=(()=>{class e extends E{value=K();disabled=x(!1,{transform:g});pcTabs=w(M(()=>O));pcTabList=w(M(()=>X));el=w(ht);ripple=u(()=>this.config.ripple());id=u(()=>`${this.pcTabs.id()}_tab_${this.value()}`);ariaControls=u(()=>`${this.pcTabs.id()}_tabpanel_${this.value()}`);active=u(()=>it(this.pcTabs.value(),this.value()));tabindex=u(()=>this.active()?this.pcTabs.tabindex():-1);mutationObserver;onFocus(t){this.pcTabs.selectOnFocus()&&this.changeActiveValue()}onClick(t){this.changeActiveValue()}onKeyDown(t){switch(t.code){case"ArrowRight":this.onArrowRightKey(t);break;case"ArrowLeft":this.onArrowLeftKey(t);break;case"Home":this.onHomeKey(t);break;case"End":this.onEndKey(t);break;case"PageDown":this.onPageDownKey(t);break;case"PageUp":this.onPageUpKey(t);break;case"Enter":case"NumpadEnter":case"Space":this.onEnterKey(t);break;default:break}t.stopPropagation()}ngAfterViewInit(){super.ngAfterViewInit(),this.bindMutationObserver()}onArrowRightKey(t){let i=this.findNextTab(t.currentTarget);i?this.changeFocusedTab(t,i):this.onHomeKey(t),t.preventDefault()}onArrowLeftKey(t){let i=this.findPrevTab(t.currentTarget);i?this.changeFocusedTab(t,i):this.onEndKey(t),t.preventDefault()}onHomeKey(t){let i=this.findFirstTab();this.changeFocusedTab(t,i),t.preventDefault()}onEndKey(t){let i=this.findLastTab();this.changeFocusedTab(t,i),t.preventDefault()}onPageDownKey(t){this.scrollInView(this.findLastTab()),t.preventDefault()}onPageUpKey(t){this.scrollInView(this.findFirstTab()),t.preventDefault()}onEnterKey(t){this.changeActiveValue(),t.preventDefault()}findNextTab(t,i=!1){let n=i?t:t.nextElementSibling;return n?R(n,"data-p-disabled")||R(n,"data-pc-section")==="inkbar"?this.findNextTab(n):n:null}findPrevTab(t,i=!1){let n=i?t:t.previousElementSibling;return n?R(n,"data-p-disabled")||R(n,"data-pc-section")==="inkbar"?this.findPrevTab(n):n:null}findFirstTab(){return this.findNextTab(this.pcTabList?.tabs?.nativeElement?.firstElementChild,!0)}findLastTab(){return this.findPrevTab(this.pcTabList?.tabs?.nativeElement?.lastElementChild,!0)}changeActiveValue(){this.pcTabs.updateValue(this.value())}changeFocusedTab(t,i){Vt(i),this.scrollInView(i)}scrollInView(t){t?.scrollIntoView?.({block:"nearest"})}bindMutationObserver(){G(this.platformId)&&(this.mutationObserver=new MutationObserver(t=>{t.forEach(()=>{this.active()&&this.pcTabList?.updateInkBar()})}),this.mutationObserver.observe(this.el.nativeElement,{childList:!0,characterData:!0,subtree:!0}))}unbindMutationObserver(){this.mutationObserver.disconnect()}ngOnDestroy(){this.mutationObserver&&this.unbindMutationObserver(),super.ngOnDestroy()}static \u0275fac=(()=>{let t;return function(n){return(t||(t=D(e)))(n||e)}})();static \u0275cmp=f({type:e,selectors:[["p-tab"]],hostVars:16,hostBindings:function(i,n){i&1&&k("focus",function(o){return n.onFocus(o)})("click",function(o){return n.onClick(o)})("keydown",function(o){return n.onKeyDown(o)}),i&2&&(h("data-pc-name","tab")("id",n.id())("aria-controls",n.ariaControls())("role","tab")("aria-selected",n.active())("data-p-disabled",n.disabled())("data-p-active",n.active())("tabindex",n.tabindex()),B("p-tab",!0)("p-tab-active",n.active())("p-disabled",n.disabled())("p-component",!0))},inputs:{value:[1,"value"],disabled:[1,"disabled"]},outputs:{value:"valueChange"},features:[gt([ot]),$],ngContentSelectors:z,decls:1,vars:0,template:function(i,n){i&1&&(_(),y(0))},dependencies:[C,at],encapsulation:2,changeDetection:0})}return e})(),rt=(()=>{class e extends E{pcTabs=w(M(()=>O));value=K(void 0);id=u(()=>`${this.pcTabs.id()}_tabpanel_${this.value()}`);ariaLabelledby=u(()=>`${this.pcTabs.id()}_tab_${this.value()}`);active=u(()=>it(this.pcTabs.value(),this.value()));static \u0275fac=(()=>{let t;return function(n){return(t||(t=D(e)))(n||e)}})();static \u0275cmp=f({type:e,selectors:[["p-tabpanel"]],hostVars:9,hostBindings:function(i,n){i&2&&(h("data-pc-name","tabpanel")("id",n.id())("role","tabpanel")("aria-labelledby",n.ariaLabelledby())("data-p-active",n.active()),B("p-tabpanel",!0)("p-component",!0))},inputs:{value:[1,"value"]},outputs:{value:"valueChange"},features:[$],ngContentSelectors:z,decls:1,vars:1,template:function(i,n){i&1&&(_(),l(0,be,1,0)),i&2&&I(n.active()?0:-1)},dependencies:[C],encapsulation:2,changeDetection:0})}return e})(),lt=(()=>{class e extends E{static \u0275fac=(()=>{let t;return function(n){return(t||(t=D(e)))(n||e)}})();static \u0275cmp=f({type:e,selectors:[["p-tabpanels"]],hostVars:6,hostBindings:function(i,n){i&2&&(h("data-pc-name","tabpanels")("role","presentation"),B("p-tabpanels",!0)("p-component",!0))},features:[$],ngContentSelectors:z,decls:1,vars:0,template:function(i,n){i&1&&(_(),y(0))},dependencies:[C],encapsulation:2,changeDetection:0})}return e})(),O=(()=>{class e extends E{value=K(void 0);scrollable=x(!1,{transform:g});lazy=x(!1,{transform:g});selectOnFocus=x(!1,{transform:g});showNavigators=x(!0,{transform:g});tabindex=x(0,{transform:wt});id=j(Ft("pn_id_"));_componentStyle=w(St);updateValue(t){this.value.update(()=>t)}static \u0275fac=(()=>{let t;return function(n){return(t||(t=D(e)))(n||e)}})();static \u0275cmp=f({type:e,selectors:[["p-tabs"]],hostVars:8,hostBindings:function(i,n){i&2&&(h("data-pc-name","tabs")("id",n.id()),B("p-tabs",!0)("p-tabs-scrollable",n.scrollable())("p-component",!0))},inputs:{value:[1,"value"],scrollable:[1,"scrollable"],lazy:[1,"lazy"],selectOnFocus:[1,"selectOnFocus"],showNavigators:[1,"showNavigators"],tabindex:[1,"tabindex"]},outputs:{value:"valueChange"},features:[Tt([St]),$],ngContentSelectors:z,decls:1,vars:0,template:function(i,n){i&1&&(_(),y(0))},dependencies:[C],encapsulation:2,changeDetection:0})}return e})(),Qt=(()=>{class e{static \u0275fac=function(i){return new(i||e)};static \u0275mod=mt({type:e});static \u0275inj=dt({imports:[O,lt,rt,X,st]})}return e})()});function he(e,s){e&1&&y(0)}var fe,ve,bt,pt=Q(()=>{L();L();fe=["*"];ve=0,bt=(()=>{class e{constructor(){this.label="",this.disabled=!1,this._autoId=`dvl-tab-${++ve}`}ngAfterContentInit(){if(this.value==null){let t=this.label.toLowerCase().replace(/[^a-z0-9]/g,"-").replace(/-+/g,"-").replace(/^-|-$/g,"")||this._autoId;this.value=t}}get resolvedValue(){return this.value??this._autoId}static{this.\u0275fac=function(i){return new(i||e)}}static{this.\u0275cmp=f({type:e,selectors:[["dvl-tab"]],viewQuery:function(i,n){if(i&1&&T(vt,7),i&2){let a;c(a=b())&&(n.content=a.first)}},inputs:{label:"label",value:"value",disabled:[2,"disabled","disabled",t=>t!=null&&`${t}`!="false"],icon:"icon"},ngContentSelectors:fe,decls:1,vars:0,template:function(i,n){i&1&&(_(),l(0,he,1,0,"ng-template"))},encapsulation:2})}}return e})()});function me(e,s){if(e&1&&(H(0),V(1,"i",4),q()),e&2){let t=m().$implicit;r(),tt(t.icon)}}function ge(e,s){if(e&1&&(H(0),d(1,"p-tab",2),l(2,me,2,2,"ng-container",3),_t(3),v(),q()),e&2){let t=s.$implicit;r(),p("value",t.resolvedValue)("disabled",t.disabled),r(),p("ngIf",t.icon),r(),yt(" ",t.label," ")}}function _e(e,s){e&1&&P(0)}function ye(e,s){if(e&1&&(H(0),d(1,"p-tabpanel",5),l(2,_e,1,0,"ng-container",6),v(),q()),e&2){let t=s.$implicit;r(),p("value",t.resolvedValue),r(),p("ngTemplateOutlet",t.content)}}var Te,Nt=Q(()=>{L();J();ct();pt();L();J();ct();Te=(()=>{class e{constructor(){this.orientation="horizontal",this.styleClass="",this.scrollable=!1,this.constrained=!1,this.valueChange=new Z,this.onChange=new Z,this.trackByValue=(t,i)=>i.resolvedValue}get computedClass(){let t=["dvl-tabs"];return this.orientation==="vertical"?t.push("p-tabs-vertical"):t.push("p-tabs-horizontal"),this.constrained&&t.push("dvl-tabs-constrained"),this.styleClass&&t.push(this.styleClass),t.join(" ")}ngOnChanges(t){t.value&&!t.value.firstChange&&(this.internalValue=t.value.currentValue)}ngAfterContentInit(){if(this.internalValue=this.value,!this.internalValue&&this.tabs?.length>0){let t=this.tabs.first;t&&(this.internalValue=t.resolvedValue,this.value=this.internalValue,this.valueChange.emit(this.internalValue))}this.tabs.changes.subscribe(()=>{if(this.internalValue&&!this.tabs.find(t=>t.resolvedValue===this.internalValue)&&this.tabs.length>0){let t=this.tabs.first;this.internalValue=t.resolvedValue,this.value=this.internalValue,this.valueChange.emit(this.internalValue)}})}onTabChange(t){this.internalValue=t,this.value=t,this.valueChange.emit(t),this.onChange.emit({originalEvent:void 0,value:t})}static{this.\u0275fac=function(i){return new(i||e)}}static{this.\u0275cmp=f({type:e,selectors:[["dvl-tabs"]],contentQueries:function(i,n,a){if(i&1&&F(a,bt,4),i&2){let o;c(o=b())&&(n.tabs=o)}},hostAttrs:[1,"dvl-tabs-container"],inputs:{orientation:"orientation",styleClass:"styleClass",scrollable:[2,"scrollable","scrollable",g],constrained:[2,"constrained","constrained",g],value:"value"},outputs:{valueChange:"valueChange",onChange:"onChange"},features:[ft],decls:5,vars:8,consts:[[3,"valueChange","value","scrollable"],[4,"ngFor","ngForOf","ngForTrackBy"],[3,"value","disabled"],[4,"ngIf"],[1,"mr-2"],[1,"dvl-tabpanel",3,"value"],[4,"ngTemplateOutlet"]],template:function(i,n){i&1&&(d(0,"p-tabs",0),k("valueChange",function(o){return n.onTabChange(o)}),d(1,"p-tablist"),l(2,ge,4,4,"ng-container",1),v(),d(3,"p-tabpanels"),l(4,ye,3,2,"ng-container",1),v()()),i&2&&(tt(n.computedClass),p("value",n.internalValue)("scrollable",n.scrollable),r(2),p("ngForOf",n.tabs)("ngForTrackBy",n.trackByValue),r(2),p("ngForOf",n.tabs)("ngForTrackBy",n.trackByValue))},dependencies:[C,Dt,$t,U,Qt,O,lt,rt,X,st],styles:[`.dvl-tabs-container{display:flex;flex-direction:column;min-height:0}.dvl-tabs{width:100%;flex:1 1 auto;min-height:0}.dvl-tabs-container .p-tab{padding:.625rem 1rem;cursor:pointer;transition:all .15s ease-in-out;border-radius:.25rem;-webkit-user-select:none;user-select:none;white-space:nowrap;font-size:.875rem;font-weight:400;background-color:transparent;color:var(--text-300)}.dvl-tabs-container .p-tab:hover:not(.p-disabled):not(.p-tab-active){background-color:var(--bg-200);color:var(--text-300)}.dvl-tabs-container .p-tab.p-tab-active{background-color:var(--bg-500);color:var(--text-400);font-weight:600}.dvl-tabs-container .p-tab.p-disabled{opacity:.4;cursor:not-allowed}.dvl-tabs-container .dvl-tabpanel.p-tabpanel{padding:0;background-color:inherit}.dvl-tabs.p-tabs-vertical{display:grid;grid-template-columns:200px minmax(0,1fr);width:100%;min-width:0;min-height:0;overflow:hidden}.dvl-tabs-container:has(.p-tabs-vertical){height:100%;overflow:hidden}.dvl-tabs.p-tabs-vertical .p-tablist{grid-column:1;height:100%;min-height:0;overflow-y:auto;overflow-x:hidden;padding:.5rem 0;min-width:0;border-right:1px solid var(--border-100);position:sticky;top:0;align-self:start}.dvl-tabs.p-tabs-vertical .p-tablist .p-tablist-tab-list{display:flex!important;flex-direction:column!important;gap:.25rem}.dvl-tabs.p-tabs-vertical .p-tab{width:100%;justify-content:flex-start}.dvl-tabs.p-tabs-vertical .p-tabpanels{grid-column:2;padding:1.5rem;height:100%;min-width:0;min-height:0;overflow-y:auto;overflow-x:hidden}.dvl-tabs.p-tabs-vertical .p-tabpanel{min-height:100%}.dvl-tabs.p-tabs-horizontal{display:flex;flex-direction:column;width:100%;min-height:0}.dvl-tabs.p-tabs-horizontal .p-tablist{border-bottom:1px solid var(--border-100);padding:0;flex-shrink:0;position:relative}.dvl-tabs.p-tabs-horizontal .p-tablist .p-tablist-tab-list{display:flex!important;flex-direction:row!important;align-items:center;gap:.5rem}.dvl-tabs.p-tabs-horizontal .p-tab{width:auto!important;flex:0 0 auto;justify-content:center}.dvl-tabs.p-tabs-horizontal .p-tabpanels{padding:.5rem 0 0;overflow:visible;background:transparent}.dvl-tabs-constrained.p-tabs-horizontal{height:100%;overflow:hidden}.dvl-tabs-constrained.p-tabs-horizontal .p-tabpanels{overflow-y:auto;overflow-x:hidden;height:100%}
`],encapsulation:2})}}return e})()});var Ce=Q(()=>{Nt();pt()});export{Qt as a,ct as b,bt as c,Te as d,Ce as e};
